**To delete a managed instance activation**

The following ``delete-activation`` example deletes a managed instance activation. ::

    aws ssm delete-activation \
        --activation-id "aa673477-d926-42c1-8757-1358cEXAMPLE"
  
This command produces no output.

For more information, see `Setting Up AWS Systems Manager for Hybrid Environments <https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-managedinstances.html>`__ in the *AWS Systems Manager User Guide*.
